grib2io.tables.section3 API documentation

# grib2io.tables.section3

View Source

     1table_3_1 = {
     2'0':'Latitude/Longitude (See Template 3.0) Also called Equidistant Cylindrical or Plate Caree',
     3'1':'Rotated Latitude/Longitude (See Template 3.1)',
     4'2':'Stretched Latitude/Longitude (See Template 3.2)',
     5'3':'Rotated and Stretched Latitude/Longitude (See Template 3.3)',
     6'4':'Variable Resolution Latitude/longitude  (See Template 3.4)',
     7'5':'Variable Resolution Rotated Latitude/longitude  (See Template 3.5)',
     8'6-9':'Reserved',
     9'10':'Mercator (See Template 3.10)',
    10'11':'Reserved',
    11'12':'Transverse Mercator  (See Template 3.12)',
    12'13':'Mercator with modelling subdomains definition  (See Template 3.13)',
    13'14-19':'Reserved',
    14'20':'Polar Stereographic Projection (Can be North or South) (See Template 3.20)',
    15'21-22':'Reserved',
    16'23':'Polar Stereographic with modelling subdomains definition  (See Template 3.23)',
    17'24-29':'Reserved',
    18'30':'Lambert Conformal (Can be Secant, Tangent, Conical, or Bipolar) (See Template 3.30)',
    19'31':'Albers Equal Area (See Template 3.31)',
    20'32':'Reserved',
    21'33':'Lambert conformal with modelling subdomains definition  (See Template 3.33)',
    22'34-39':'Reserved',
    23'40':'Gaussian Latitude/Longitude (See  Template 3.40)',
    24'41':'Rotated Gaussian Latitude/Longitude (See Template 3.41)',
    25'42':'Stretched Gaussian Latitude/Longitude (See Template 3.42)',
    26'43':'Rotated and Stretched Gaussian Latitude/Longitude (See Template 3.43)',
    27'44-49':'Reserved',
    28'50':'Spherical Harmonic Coefficients (See Template 3.50)',
    29'51':'Rotated Spherical Harmonic Coefficients (See Template 3.51)',
    30'52':'Stretched Spherical Harmonic Coefficients (See Template 3.52)',
    31'53':'Rotated and Stretched Spherical Harmonic Coefficients (See Template 3.53)',
    32'54-59':'Reserved',
    33'60':'Cubed-Sphere Gnomonic  (See Template 3.60) Validation',
    34'61':'Spectral Mercator with modelling subdomains definition  (See Template 3.61)',
    35'62':'Spectral Polar Stereographic with modelling subdomains definition  (See Template 3.62)',
    36'63':'Spectral Lambert conformal with modelling subdomains definition  (See Template 3.63)',
    37'64-89':'Reserved',
    38'90':'Space View Perspective or Orthographic (See Template 3.90)',
    39'91-99':'Reserved',
    40'100':'Triangular Grid Based on an Icosahedron (See Template 3.100)',
    41'101':'General Unstructured Grid (see Template 3.101)',
    42'102-109':'Reserved',
    43'110':'Equatorial Azimuthal Equidistant Projection (See Template 3.110)',
    44'111-119':'Reserved',
    45'120':'Azimuth-Range Projection (See Template 3.120)',
    46'121-139':'Reserved',
    47'140':'Lambert Azimuthal Equal Area Projection  (See Template 3.140)',
    48'141-203':'Reserved',
    49'204':'Curvilinear Orthogonal Grids (See Template 3.204)',
    50'205-999':'Reserved',
    51'1000':'Cross Section Grid with Points Equally Spaced on the Horizontal (See Template 3.1000)',
    52'1001-1099':'Reserved',
    53'1100':'Hovmoller Diagram with Points Equally Spaced on the Horizontal (See Template 3.1100)',
    54'1101-1199':'Reserved',
    55'1200':'Time Section Grid (See Template 3.1200)',
    56'1201-32767':'Reserved',
    57'32768-65534':'Reserved for Local Use',
    58'32768':'Rotated Latitude/Longitude  (Arakawa Staggered E-Grid) (See Template 3.32768)',
    59'32769':'Rotated Latitude/Longitude  (Arakawa Non-E Staggered Grid) (See Template 3.32769)',
    60'65535':'Missing',
    61}
    62
    63table_3_2 = {
    64'0':'Earth assumed spherical with radius = 6,367,470.0 m',
    65'1':'Earth assumed spherical with radius specified (in m) by data producer',
    66'2':'Earth assumed oblate spheriod with size as determined by IAU in 1965 (major axis = 6,378,160.0 m, minor axis = 6,356,775.0 m, f = 1/297.0)',
    67'3':'Earth assumed oblate spheriod with major and minor axes specified (in km) by data producer',
    68'4':'Earth assumed oblate spheriod as defined in IAG-GRS80 model (major axis = 6,378,137.0 m, minor axis = 6,356,752.314 m, f = 1/298.257222101)',
    69'5':'Earth assumed represented by WGS84 (as used by ICAO since 1998) (Uses IAG-GRS80 as a basis)',
    70'6':'Earth assumed spherical with radius = 6,371,229.0 m',
    71'7':'Earth assumed oblate spheroid with major and minor axes  specified (in m) by data producer',
    72'8':'Earth model assumed spherical with radius 6,371,200 m,  but the horizontal datum of the resulting Latitude/Longitude field is  the WGS84 reference frame',
    73'9':'Earth represented by the OSGB 1936 Datum,  using the Airy_1830 Spheroid, the Greenwich meridian as 0 Longitude, the Newlyn datum as mean sea  level, 0 height.',
    74'10-191':'Reserved',
    75'192-254':'Reserved for Local Use',
    76'255':'Missing',
    77}
    78
    79earth_params = {
    80'0':{'shape':'spherical','radius':6367470.0},
    81'1':{'shape':'spherical','radius':None},
    82'2':{'shape':'oblateSpheriod','major_axis':6378160.0,'minor_axis':6356775.0,'flattening':1.0/297.0},
    83'3':{'shape':'oblateSpheriod','major_axis':None,'minor_axis':None,'flattening':None},
    84'4':{'shape':'oblateSpheriod','major_axis':6378137.0,'minor_axis':6356752.314,'flattening':1.0/298.257222101},
    85'5':{'shape':'oblateSpheriod','major_axis':6378137.0,'minor_axis':6356752.3142,'flattening':1.0/298.257223563},
    86'6':{'shape':'spherical','radius':6371229.0},
    87'7':{'shape':'oblateSpheriod','major_axis':None,'minor_axis':None,'flattening':None},
    88'8':{'shape':'spherical','radius':6371200.0},
    89}
    90for i in range(9,256):
    91    earth_params[str(i)] = {'shape':'unknown','radius':None}